@@ -1,12 +1,9 @@
 # Module: internal.persistence
 # Author: Moez Ali <moez.ali@queensu.ca> and Antoni Baum (Yard1) <antoni.baum@protonmail.com>
 # License: MIT
-
 import gc
 from typing import Dict, Optional
-
 from sklearn.pipeline import Pipeline
-
 from pycaret.internal.utils import get_logger
 
 
@@ -73,7 +70,7 @@ def deploy_model(
         Dictionary of applicable authentication tokens.
 
         When platform = 'aws':
-        {'bucket' : 'Name of Bucket on S3'}
+        {'bucket' : 'Name of Bucket on S3', 'path': (optional) folder name under the bucket}
 
         When platform = 'gcp':
         {'project': 'gcp_pycaret', 'bucket' : 'pycaret-test'}
@@ -152,7 +149,10 @@ def deploy_model(
         logger.info("Initializing S3 client")
         s3 = boto3.client("s3")
         filename = f"{model_name}.pkl"
-        key = f"{model_name}.pkl"
+        if "path" in authentication:
+            key = os.path.join(authentication.get("path"), f"{model_name}.pkl")
+        else:
+            key = f"{model_name}.pkl"
         bucket_name = authentication.get("bucket")
 
         if bucket_name is None:
@@ -348,7 +348,7 @@ def load_model(
         dictionary of applicable authentication tokens.
 
         When platform = 'aws':
-        {'bucket' : 'Name of Bucket on S3'}
+        {'bucket' : 'Name of Bucket on S3', 'path': (optional) folder name under the bucket}
 
         When platform = 'gcp':
         {'project': 'gcp_pycaret', 'bucket' : 'pycaret-test'}
@@ -415,11 +415,17 @@ def load_model(
             raise ValueError('S3 bucket name missing. Provide `bucket` name as part of authentication parameter')
 
         filename = f"{model_name}.pkl"
+
+        if "path" in authentication:
+            key = os.path.join(authentication.get("path"), filename)
+        else:
+            key = filename
+
         index = filename.rfind("/")
         s3 = boto3.resource("s3")
 
         if index == -1:
-            s3.Bucket(bucketname).download_file(filename, filename)
+            s3.Bucket(bucketname).download_file(key, filename)
         else:
             path, key = filename[: index + 1], filename[index + 1:]
             if not os.path.exists(path):
